==> ejc-probid-impl-3.0.0-20220809.074906-68-sources.jar: com/ejianc/business/win/bean/WinEntity.java <==
package com.ejianc.business.win.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 中标登记实体
 *
 * @author generator
 */
@TableName("ejc_probid_bid_win_register")
public class WinEntity extends BaseEntity {
	private static final long serialVersionUID = 5135061968145474673L;

	@TableField(value = "employee_id")
	private Long employeeId; // 填报人（经办人）id
	@TableField(value = "employee_name")
	private String employeeName; // 填报人（经办人）名称
	@TableField(value = "commit_date")
	private Date commitDate; // 提交日期
	@TableField(value = "commit_user_name")
	private String commitUserName; // 提交人名称
	@TableField(value = "commit_user_code")
	private String commitUserCode; // 提交人账号
	@TableField(value = "effective_date")
	private Date effectiveDate; // 生效日期
	@TableField(value = "bill_code")
	private String billCode; // 单据编码
	@TableField(value = "bill_name")
	private String billName; // 单据名称
	@TableField(value = "bill_type")
	private String billType; // 单据类型
	@TableField(value = "bill_state")
	private Integer billState; // 单据状态
	@TableField(value = "bill_state_name")
	private String billStateName; // 单据状态名称
	@TableField(value = "project_id")
	private Long projectId; // 项目id
	@TableField(value = "project_code")
	private String projectCode; // 项目编码
	@TableField(value = "project_name")
	private String projectName; // 项目名称
	@TableField(value = "project_type_id")
	private String projectTypeId; // 项目类型id
	@TableField(value = "project_type_name")
	private String projectTypeName; // 项目类型名称
	@TableField(value = "construction_unit")
	private String constructionUnit; // 建设单位
	@TableField(value = "registration_deadline")
	private Date registrationDeadline; // 报名截止日期
	@TableField(value = "bid_open_date")
	private Date bidOpenDate; // 开标日期
	@TableField(value = "bid_unit_id")
	private Long bidUnitId; // 投标单位id
	@TableField(value = "bid_unit_code")
	private String bidUnitCode; // 投标单位编码
	@TableField(value = "bid_unit_name")
	private String bidUnitName; // 投标单位名称
	@TableField(value = "bid_win_flag")
	private String bidWinFlag; // 是否中标 0-否，1-是
	@TableField(value = "bid_win_flag_name")
	private String bidWinFlagName; // 是否中标名称
	@TableField(value = "bid_win_company_name")
	private String bidWinCompanyName; // 中标单位
	@TableField(value = "bid_win_mny")
	private BigDecimal bidWinMny; // 中标金额
	@TableField(value = "handle_date")
	private Date handleDate; // 填报日期


	public Long getEmployeeId() {
		return employeeId;
	}

	public void setEmployeeId(Long employeeId) {
		this.employeeId = employeeId;
	}

	public String getEmployeeName() {
		return employeeName;
	}

	public void setEmployeeName(String employeeName) {
		this.employeeName = employeeName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public Date getEffectiveDate() {
		return effectiveDate;
	}

	public void setEffectiveDate(Date effectiveDate) {
		this.effectiveDate = effectiveDate;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public String getBillName() {
		return billName;
	}

	public void setBillName(String billName) {
		this.billName = billName;
	}

	public String getBillType() {
		return billType;
	}

	public void setBillType(String billType) {
		this.billType = billType;
	}

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public String getBillStateName() {
		return billStateName;
	}

	public void setBillStateName(String billStateName) {
		this.billStateName = billStateName;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectCode() {
		return projectCode;
	}

	public void setProjectCode(String projectCode) {
		this.projectCode = projectCode;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getProjectTypeId() {
		return projectTypeId;
	}

	public void setProjectTypeId(String projectTypeId) {
		this.projectTypeId = projectTypeId;
	}

	public String getProjectTypeName() {
		return projectTypeName;
	}

	public void setProjectTypeName(String projectTypeName) {
		this.projectTypeName = projectTypeName;
	}

	public String getConstructionUnit() {
		return constructionUnit;
	}

	public void setConstructionUnit(String constructionUnit) {
		this.constructionUnit = constructionUnit;
	}

	public Date getRegistrationDeadline() {
		return registrationDeadline;
	}

	public void setRegistrationDeadline(Date registrationDeadline) {
		this.registrationDeadline = registrationDeadline;
	}

	public Date getBidOpenDate() {
		return bidOpenDate;
	}

	public void setBidOpenDate(Date bidOpenDate) {
		this.bidOpenDate = bidOpenDate;
	}

	public Long getBidUnitId() {
		return bidUnitId;
	}

	public void setBidUnitId(Long bidUnitId) {
		this.bidUnitId = bidUnitId;
	}

	public String getBidUnitCode() {
		return bidUnitCode;
	}

	public void setBidUnitCode(String bidUnitCode) {
		this.bidUnitCode = bidUnitCode;
	}

	public String getBidUnitName() {
		return bidUnitName;
	}

	public void setBidUnitName(String bidUnitName) {
		this.bidUnitName = bidUnitName;
	}

	public String getBidWinFlag() {
		return bidWinFlag;
	}

	public void setBidWinFlag(String bidWinFlag) {
		this.bidWinFlag = bidWinFlag;
	}

	public String getBidWinFlagName() {
		return bidWinFlagName;
	}

	public void setBidWinFlagName(String bidWinFlagName) {
		this.bidWinFlagName = bidWinFlagName;
	}

	public String getBidWinCompanyName() {
		return bidWinCompanyName;
	}

	public void setBidWinCompanyName(String bidWinCompanyName) {
		this.bidWinCompanyName = bidWinCompanyName;
	}

	public BigDecimal getBidWinMny() {
		return bidWinMny;
	}

	public void setBidWinMny(BigDecimal bidWinMny) {
		this.bidWinMny = bidWinMny;
	}

	public Date getHandleDate() {
		return handleDate;
	}

	public void setHandleDate(Date handleDate) {
		this.handleDate = handleDate;
	}

}

==> ejc-probid-impl-3.0.0-20221219.112734-85-sources.jar: com/ejianc/business/win/bean/WinEntity.java <==
package com.ejianc.business.win.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 中标登记实体
 *
 * @author generator
 */
@TableName("ejc_probid_bid_win_register")
public class WinEntity extends BaseEntity {
	private static final long serialVersionUID = 5135061968145474673L;

	@TableField(value = "employee_id")
	private Long employeeId; // 填报人（经办人）id
	@TableField(value = "employee_name")
	private String employeeName; // 填报人（经办人）名称
	@TableField(value = "commit_date")
	private Date commitDate; // 提交日期
	@TableField(value = "commit_user_name")
	private String commitUserName; // 提交人名称
	@TableField(value = "commit_user_code")
	private String commitUserCode; // 提交人账号
	@TableField(value = "effective_date")
	private Date effectiveDate; // 生效日期
	@TableField(value = "bill_code")
	private String billCode; // 单据编码
	@TableField(value = "bill_name")
	private String billName; // 单据名称
	@TableField(value = "bill_type")
	private String billType; // 单据类型
	@TableField(value = "bill_state")
	private Integer billState; // 单据状态
	@TableField(value = "bill_state_name")
	private String billStateName; // 单据状态名称
	@TableField(value = "project_id")
	private Long projectId; // 项目id
	@TableField(value = "project_code")
	private String projectCode; // 项目编码
	@TableField(value = "project_name")
	private String projectName; // 项目名称
	@TableField(value = "project_type_id")
	private String projectTypeId; // 项目类型id
	@TableField(value = "project_type_name")
	private String projectTypeName; // 项目类型名称
	@TableField(value = "construction_unit")
	private String constructionUnit; // 建设单位
	@TableField(value = "registration_deadline")
	private Date registrationDeadline; // 报名截止日期
	@TableField(value = "bid_open_date")
	private Date bidOpenDate; // 开标日期
	@TableField(value = "bid_unit_id")
	private Long bidUnitId; // 投标单位id
	@TableField(value = "bid_unit_code")
	private String bidUnitCode; // 投标单位编码
	@TableField(value = "bid_unit_name")
	private String bidUnitName; // 投标单位名称
	@TableField(value = "bid_win_flag")
	private String bidWinFlag; // 是否中标 0-否，1-是
	@TableField(value = "bid_win_flag_name")
	private String bidWinFlagName; // 是否中标名称
	@TableField(value = "bid_win_company_name")
	private String bidWinCompanyName; // 中标单位
	@TableField(value = "bid_win_mny")
	private BigDecimal bidWinMny; // 中标金额
	@TableField(value = "handle_date")
	private Date handleDate; // 填报日期
	@TableField(value = "project_total_area")
	private BigDecimal projectTotalArea; // 建筑面积


	public Long getEmployeeId() {
		return employeeId;
	}

	public void setEmployeeId(Long employeeId) {
		this.employeeId = employeeId;
	}

	public String getEmployeeName() {
		return employeeName;
	}

	public void setEmployeeName(String employeeName) {
		this.employeeName = employeeName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public Date getEffectiveDate() {
		return effectiveDate;
	}

	public void setEffectiveDate(Date effectiveDate) {
		this.effectiveDate = effectiveDate;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public String getBillName() {
		return billName;
	}

	public void setBillName(String billName) {
		this.billName = billName;
	}

	public String getBillType() {
		return billType;
	}

	public void setBillType(String billType) {
		this.billType = billType;
	}

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public String getBillStateName() {
		return billStateName;
	}

	public void setBillStateName(String billStateName) {
		this.billStateName = billStateName;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectCode() {
		return projectCode;
	}

	public void setProjectCode(String projectCode) {
		this.projectCode = projectCode;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getProjectTypeId() {
		return projectTypeId;
	}

	public void setProjectTypeId(String projectTypeId) {
		this.projectTypeId = projectTypeId;
	}

	public String getProjectTypeName() {
		return projectTypeName;
	}

	public void setProjectTypeName(String projectTypeName) {
		this.projectTypeName = projectTypeName;
	}

	public String getConstructionUnit() {
		return constructionUnit;
	}

	public void setConstructionUnit(String constructionUnit) {
		this.constructionUnit = constructionUnit;
	}

	public Date getRegistrationDeadline() {
		return registrationDeadline;
	}

	public void setRegistrationDeadline(Date registrationDeadline) {
		this.registrationDeadline = registrationDeadline;
	}

	public Date getBidOpenDate() {
		return bidOpenDate;
	}

	public void setBidOpenDate(Date bidOpenDate) {
		this.bidOpenDate = bidOpenDate;
	}

	public Long getBidUnitId() {
		return bidUnitId;
	}

	public void setBidUnitId(Long bidUnitId) {
		this.bidUnitId = bidUnitId;
	}

	public String getBidUnitCode() {
		return bidUnitCode;
	}

	public void setBidUnitCode(String bidUnitCode) {
		this.bidUnitCode = bidUnitCode;
	}

	public String getBidUnitName() {
		return bidUnitName;
	}

	public void setBidUnitName(String bidUnitName) {
		this.bidUnitName = bidUnitName;
	}

	public String getBidWinFlag() {
		return bidWinFlag;
	}

	public void setBidWinFlag(String bidWinFlag) {
		this.bidWinFlag = bidWinFlag;
	}

	public String getBidWinFlagName() {
		return bidWinFlagName;
	}

	public void setBidWinFlagName(String bidWinFlagName) {
		this.bidWinFlagName = bidWinFlagName;
	}

	public String getBidWinCompanyName() {
		return bidWinCompanyName;
	}

	public void setBidWinCompanyName(String bidWinCompanyName) {
		this.bidWinCompanyName = bidWinCompanyName;
	}

	public BigDecimal getBidWinMny() {
		return bidWinMny;
	}

	public void setBidWinMny(BigDecimal bidWinMny) {
		this.bidWinMny = bidWinMny;
	}

	public Date getHandleDate() {
		return handleDate;
	}

	public void setHandleDate(Date handleDate) {
		this.handleDate = handleDate;
	}

	public BigDecimal getProjectTotalArea() {
		return projectTotalArea;
	}

	public void setProjectTotalArea(BigDecimal projectTotalArea) {
		this.projectTotalArea = projectTotalArea;
	}
}
